==> wpackagist-plugin-complianz-gdpr-premium-3.1.0.zip: pro/config/EU/questions-processing.php <==
<?php
defined('ABSPATH') or die("you do not have acces to this page!");
$this->fields = $this->fields + array(
        'has-wizard-been-completed-dataleak' => array(
            'step' => 1,
            'section' => 1,
            'source' => 'processing-eu',
            'type' => 'text',
            'default' => '',
            'callback' => 'is_wizard_completed',
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'processor-activities' => array(
            'step' => 2,
            'section' => 1,
            'source' => 'processing-eu',
            'translatable' => true,
            'type' => 'text',
            'default' => '',
            'required' => true,
            'help' => __('E.g. hosting, data storage, payment processing, sending newsletters', 'complianz-gdpr'),
            'label' => __("Describe briefly what activities your processor will perform.", 'complianz-gdpr'),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'data-from-whom' => array(
            'step' => 2,
            'section' => 1,
            'source' => 'processing-eu',
            'type' => 'multicheckbox',
            'default' => '',
            'required' => true,
            'label' => __("Who's data will be processed?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('Customers', 'complianz-gdpr'),
                '2' => __('Employees', 'complianz-gdpr'),
                '3' => __('Suppliers', 'complianz-gdpr'),
                '4' => __('Account holders', 'complianz-gdpr'),
                '5' => __('Job applicants', 'complianz-gdpr'),
                '6' => __('Website visitors', 'complianz-gdpr'),
                '7' => __('Patients', 'complianz-gdpr'),
                '8' => __('Leads', 'complianz-gdpr'),
                '9' => __('Members', 'complianz-gdpr'),
                '10' => __('Tenants', 'complianz-gdpr'),
                '11' => __('Other:', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'data-from-whom-other' => array(
            'step' => 2,
            'section' => 1,
            'source' => 'processing-eu',
            'type' => 'text',
            'translatable' => true,
            'default' => '',
            'required' => true,
            'label' => __("Which categories can the persons be placed in?", 'complianz-gdpr'),
            'help' => __('Multiple categories should be separated with a semi-colon.'),
            'condition' => array('data-from-whom' => '11'),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'what-kind-of-data' => array(
            'step' => 2,
            'section' => 1,
            'source' => 'processing-eu',
            'type' => 'multicheckbox',
            'default' => '',
            'required' => true,
            'label' => __("What kind of data will be processed by the data processor?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('Name Address City', 'complianz-gdpr'),
                '2' => __('Phone number', 'complianz-gdpr'),
                '3' => __('Email address', 'complianz-gdpr'),
                '4' => __('Browse history', 'complianz-gdpr'),
                '5' => __('IP Address', 'complianz-gdpr'),
                '6' => __('Social Media accounts', 'complianz-gdpr'),
                '7' => __("Photo's", 'complianz-gdpr'),
                '8' => __('Curriculum Vitae', 'complianz-gdpr'),
                '9' => __('Birth Date', 'complianz-gdpr'),
                '10' => __('Marital status', 'complianz-gdpr'),
                '11' => __('Financial data', 'complianz-gdpr'),
                '12' => __('Medical data', 'complianz-gdpr'),
                '13' => __('Other:', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'what-kind-of-data-other' => array(
            'step' => 2,
            'section' => 1,
            'source' => 'processing-eu',
            'type' => 'text',
            'translatable' => true,
            'default' => '',
            'required' => true,
            'label' => __("Which kind of personal data will be processed?", 'complianz-gdpr'),
            'help' => __('Multiple categories should be separated with a semi - colon.'),
            'condition' => array('what-kind-of-data' => '13'),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'allow-outside-eu' => array(
            'step' => 2,
            'section' => 1,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'required' => true,
            'label' => __("Do you allow data to be processed outside the EEA European Economic Area?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('No, processing outside the EEA is not allowed. ', 'complianz-gdpr'),
                '2' => __('Yes, but only when the countries share the same security levels concerning privacy. ', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        // CONTACTGEGEVENS PERSOON - CONTACT DETAILS

        'name_of_processor' => array(
            'step' => 2,
            'section' => 2,
            'source' => 'processing-eu',
            'type' => 'text',
            'default' => '',
            'required' => true,
            'label' => __("What is the name of the processor?", 'complianz-gdpr'),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),

        // HANDLING REQUESTS FROM THOSE involved

        'deal_with_requests' => array(
            'step' => 2,
            'section' => 2,
            'source' => 'processing-eu',
            'type' => 'multicheckbox',
            'default' => '',
            'required' => true,
            'label' => __("How will you deal with requests from those involved?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('I will deal with requests from those involved, The processor will forward everything to me. ', 'complianz-gdpr'),
                '2' => __('The processor may charge additional costs that it incurs in this context. ', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'security_measures' => array(
            'step' => 2,
            'section' => 2,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'required' => true,
            'label' => __("Which security measures should the Processor take?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('The Processor must at least be able to meet the legal minimum. ', 'complianz-gdpr'),
                '2' => __('The Processor must comply with a separate security protocol. ', 'complianz-gdpr'),
                '3' => __('I want to be able to choose the required security measures myself. ', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'security-protocol-where' => array(
            'step' => 2,
            'section' => 2,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'label' => __("Where can people find this security protocol?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('The protocol is annexed to this agreement. ', 'complianz-gdpr'),
                '2' => __('The protocol can be found online via an URL', 'complianz-gdpr'),
            ),
            'condition' => array('security_measures' => '2'),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'security-protocol-where-url' => array(
            'step' => 2,
            'section' => 2,
            'source' => 'processing-eu',
            'type' => 'url',
            'default' => '',
            'label' => __("What is the URL?", 'complianz-gdpr'),
            'condition' => array('security-protocol-where' => '2'),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'processing-security-measures' => array(
            'step' => 2,
            'section' => 2,
            'source' => 'processing-eu',
            'type' => 'multicheckbox',
            'default' => '',
            'label' => __("Select the required security standard or measure.", 'complianz-gdpr'),
            'condition' => array('security_measures' => '3'),
            'options' => array(
                '1' => __('PCI Security Standards', 'complianz-gdpr'),
                '2' => __('Username and password', 'complianz-gdpr'),
                '3' => __('DNSSEC', 'complianz-gdpr'),
                '4' => __('TLS / SSL', 'complianz-gdpr'),
                '5' => __('DKIM, SPF en DMARC', 'complianz-gdpr'),
                '6' => __('Security software', 'complianz-gdpr'),
                '7' => __('ISO27001 / 27002 certified', 'complianz-gdpr'),
                '8' => __('Access security', 'complianz-gdpr'),
                '9' => __('Other:', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'processing-security-measures-other' => array(
            'step' => 2,
            'section' => 2,
            'source' => 'processing-eu',
            'type' => 'textarea',
            'default' => '',
            'label' => __("Other:", 'complianz-gdpr'),
            'condition' => array('processing-security-measures' => '9'),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        // RIGHT OF AUDIT

        'audit' => array(
            'step' => 2,
            'section' => 3,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'required' => true,
            'label' => __("Can the audit be carried out by an independent third party?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('The audit may be performed by an independent third party. ', 'complianz-gdpr'),
                '2' => __('Only I can perform audits', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),

        'when-audit' => array(
            'step' => 2,
            'section' => 3,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'required' => true,
            'label' => __("When can you, as the as the data controller, carry out audits?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('If similar reports give no or insufficient clarification.', 'complianz-gdpr'),
                '2' => __('With a reasonable suspicion of abuse,', 'complianz-gdpr'),
                '3' => __('Once every quarter and more often with reasonable suspicion of abuse.', 'complianz-gdpr'),
                '4' => __('Once every year and more often with reasonable suspicion of abuse.', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'what-do-with-findings' => array(
            'step' => 2,
            'section' => 3,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'required' => true,
            'label' => __("What should be done with the findings of the audit?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('The processor is obliged to implement the findings as quickly as possible. ', 'complianz-gdpr'),
                '2' => __('The parties should decide together what to do with these findings. ', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),

        'audit-costs' => array(
            'step' => 2,
            'section' => 3,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'required' => true,
            'label' => __("Who is responsible for any audit costs?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('Data controller', 'complianz-gdpr'),
                '2' => __('Processor', 'complianz-gdpr'),
                '3' => __('The Processor, in case of non - trivial violations of the obligations from the processor agreement. Otherwise the data controller. ', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),

        // DATA breach
        'when-informed' => array(
            'step' => 3,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'required' => true,
            'label' => __("How quickly should the Data Controller be informed of a data breach?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('Immediately (without unreasonable delay) after the leak has become known to the processor. ', 'complianz-gdpr'),
                '2' => __('Immediately (without unreasonable delay), within 24 hours after the leak has become know to the processor. ', 'complianz-gdpr'),
                '3' => __('Immediately (without unreasonable delay), within 36 hours after the leak has become know to the processor. ', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'maximize-liability' => array(
            'step' => 3,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'required' => true,
            'label' => __("Do you want to limit liability?", 'complianz-gdpr'),
            'options' => $this->yes_no,
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),

        'amount-liable' => array(
            'step' => 3,
            'source' => 'processing-eu',
            'type' => 'text',
            'default' => '',
            'placeholder' => __('0.00 $','complianz-gdpr'),
            'condition' => array('maximize-liability' =>'yes'),
            'required' => true,
            'label' => __("What is the maximum liability for violations of the processor agreement?", 'complianz-gdpr'),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'insurance' => array(
            'step' => 3,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'required' => true,
            'label' => __("Should the Processor take out liability insurance?", 'complianz-gdpr'),
            'options' => $this->yes_no,
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'max_cost_of_insurance' => array(
            'step' => 3,
            'source' => 'processing-eu',
            'type' => 'text',
            'default' => '',
            'required' => true,
            'placeholder' => __('0.00 $','complianz-gdpr'),
            'label' => __("What is the minimum amount the insurance should cover?", 'complianz-gdpr'),
            'condition' => array('insurance' => 'yes'),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'insurance_conditions' => array(
            'step' => 3,
            'source' => 'processing-eu',
            'type' => 'multicheckbox',
            'default' => '',
            'required' => true,
            'condition' => array('insurance' => 'yes'),
            'label' => __("The insurance conditions must provide at least cover for the following claims:", 'complianz-gdpr'),
            'options' => array(
                '1' => __('Data breaches.', 'complianz-gdpr'),
                '2' => __('Not complying to the processing data contract. ', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'access-to-policy' => array(
            'step' => 3,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'required' => true,
            'condition' => array('insurance' => 'yes'),
            'options' => $this->yes_no,
            'label' => __("Access to the insurance policy can be demanded.", 'complianz-gdpr'),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'finish_setup_processing' => array(
            'step' => '4',
            'source' => 'processing-eu',
            'callback' => 'processing_last_step',
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
    );

==> wpackagist-plugin-complianz-gdpr-premium-4.0.6.zip: pro/config/EU/questions-processing.php <==
<?php
defined('ABSPATH') or die("you do not have acces to this page!");
$this->fields = $this->fields + array(
        'has-wizard-been-completed-dataleak' => array(
            'step' => 1,
            'section' => 1,
            'source' => 'processing-eu',
            'type' => 'text',
            'default' => '',
            'callback' => 'is_wizard_completed',
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'processor-activities' => array(
            'step' => 2,
            'section' => 1,
            'source' => 'processing-eu',
            'translatable' => true,
            'type' => 'text',
            'default' => '',
            'required' => true,
            'help' => __('E.g. hosting, data storage, payment processing, sending newsletters', 'complianz-gdpr'),
            'label' => __("Describe briefly what activities your processor will perform.", 'complianz-gdpr'),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'data-from-whom' => array(
            'step' => 2,
            'section' => 1,
            'source' => 'processing-eu',
            'type' => 'multicheckbox',
            'default' => '',
            'required' => true,
            'label' => __("Who's data will be processed?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('Customers', 'complianz-gdpr'),
                '2' => __('Employees', 'complianz-gdpr'),
                '3' => __('Suppliers', 'complianz-gdpr'),
                '4' => __('Account holders', 'complianz-gdpr'),
                '5' => __('Job applicants', 'complianz-gdpr'),
                '6' => __('Website visitors', 'complianz-gdpr'),
                '7' => __('Patients', 'complianz-gdpr'),
                '8' => __('Leads', 'complianz-gdpr'),
                '9' => __('Members', 'complianz-gdpr'),
                '10' => __('Tenants', 'complianz-gdpr'),
                '11' => __('Other:', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'data-from-whom-other' => array(
            'step' => 2,
            'section' => 1,
            'source' => 'processing-eu',
            'type' => 'text',
            'translatable' => true,
            'default' => '',
            'required' => true,
            'label' => __("Which categories can the persons be placed in?", 'complianz-gdpr'),
            'help' => __('Multiple categories should be separated with a semi-colon.'),
            'condition' => array('data-from-whom' => '11'),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'what-kind-of-data' => array(
            'step' => 2,
            'section' => 1,
            'source' => 'processing-eu',
            'type' => 'multicheckbox',
            'default' => '',
            'required' => true,
            'label' => __("What kind of data will be processed by the data processor?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('Name Address City', 'complianz-gdpr'),
                '2' => __('Phone number', 'complianz-gdpr'),
                '3' => __('Email address', 'complianz-gdpr'),
                '4' => __('Browse history', 'complianz-gdpr'),
                '5' => __('IP Address', 'complianz-gdpr'),
                '6' => __('Social Media accounts', 'complianz-gdpr'),
                '7' => __("Photo's", 'complianz-gdpr'),
                '8' => __('Curriculum Vitae', 'complianz-gdpr'),
                '9' => __('Birth Date', 'complianz-gdpr'),
                '10' => __('Marital status', 'complianz-gdpr'),
                '11' => __('Financial data', 'complianz-gdpr'),
                '12' => __('Medical data', 'complianz-gdpr'),
                '13' => __('Other:', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'what-kind-of-data-other' => array(
            'step' => 2,
            'section' => 1,
            'source' => 'processing-eu',
            'type' => 'text',
            'translatable' => true,
            'default' => '',
            'required' => true,
            'label' => __("Which kind of personal data will be processed?", 'complianz-gdpr'),
            'help' => __('Multiple categories should be separated with a semi - colon.'),
            'condition' => array('what-kind-of-data' => '13'),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'allow-outside-eu' => array(
            'step' => 2,
            'section' => 1,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'required' => true,
            'label' => __("Do you allow data to be processed outside the EEA European Economic Area?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('No, processing outside the EEA is not allowed. ', 'complianz-gdpr'),
                '2' => __('Yes, but only when the countries share the same security levels concerning privacy. ', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        // CONTACTGEGEVENS PERSOON - CONTACT DETAILS

        'name_of_processor' => array(
            'step' => 2,
            'section' => 2,
            'source' => 'processing-eu',
            'type' => 'text',
            'default' => '',
            'required' => true,
            'label' => __("What is the name of the processor?", 'complianz-gdpr'),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),

        // HANDLING REQUESTS FROM THOSE involved

        'deal_with_requests' => array(
            'step' => 2,
            'section' => 2,
            'source' => 'processing-eu',
            'type' => 'multicheckbox',
            'default' => 1,
            'required' => true,
            'label' => __("How will you deal with requests from those involved?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('I will deal with requests from those involved, The processor will forward everything to me. ', 'complianz-gdpr'),
                '2' => __('The processor may charge additional costs that it incurs in this context. ', 'complianz-gdpr'),
            ),
            'help' => __('An individual can make a subject access request to you verbally or in writing. It can also be made to any part of your organisation (including by social media) and does not have to be to a specific person or contact point.','complianz-gdpr'),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'security_measures' => array(
            'step' => 2,
            'section' => 2,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'required' => true,
            'label' => __("Which security measures should the Processor take?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('The Processor must at least be able to meet the legal minimum. ', 'complianz-gdpr'),
                '2' => __('The Processor must comply with a separate security protocol. ', 'complianz-gdpr'),
                '3' => __('I want to be able to choose the required security measures myself. ', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'security-protocol-where' => array(
            'step' => 2,
            'section' => 2,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'label' => __("Where can people find this security protocol?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('The protocol is annexed to this agreement. ', 'complianz-gdpr'),
                '2' => __('The protocol can be found online via an URL', 'complianz-gdpr'),
            ),
            'condition' => array('security_measures' => '2'),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'security-protocol-where-url' => array(
            'step' => 2,
            'section' => 2,
            'source' => 'processing-eu',
            'type' => 'url',
            'default' => '',
            'label' => __("What is the URL?", 'complianz-gdpr'),
            'condition' => array('security-protocol-where' => '2'),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'processing-security-measures' => array(
            'step' => 2,
            'section' => 2,
            'source' => 'processing-eu',
            'type' => 'multicheckbox',
            'default' => '',
            'label' => __("Select the required security standard or measure.", 'complianz-gdpr'),
            'condition' => array('security_measures' => '3'),
            'options' => array(
                '1' => __('PCI Security Standards', 'complianz-gdpr'),
                '2' => __('Username and password', 'complianz-gdpr'),
                '3' => __('DNSSEC', 'complianz-gdpr'),
                '4' => __('TLS / SSL', 'complianz-gdpr'),
                '5' => __('DKIM, SPF en DMARC', 'complianz-gdpr'),
                '6' => __('Security software', 'complianz-gdpr'),
                '7' => __('ISO27001 / 27002 certified', 'complianz-gdpr'),
                '8' => __('Access security', 'complianz-gdpr'),
                '9' => __('Other:', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'processing-security-measures-other' => array(
            'step' => 2,
            'section' => 2,
            'source' => 'processing-eu',
            'type' => 'textarea',
            'default' => '',
            'label' => __("Other:", 'complianz-gdpr'),
            'condition' => array('processing-security-measures' => '9'),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        // RIGHT OF AUDIT
        'when-audit' => array(
            'step' => 2,
            'section' => 3,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'required' => true,
            'label' => __("When can you, as the data controller, carry out audits?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('If similar reports give no or insufficient clarification.', 'complianz-gdpr'),
                '2' => __('With a reasonable suspicion of abuse,', 'complianz-gdpr'),
                '3' => __('Once every quarter and more often with reasonable suspicion of abuse.', 'complianz-gdpr'),
                '4' => __('Once every year and more often with reasonable suspicion of abuse.', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'audit' => array(
            'step' => 2,
            'section' => 3,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'required' => true,
            'label' => __("Can the audit be carried out by an independent third party?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('The audit may be performed by an independent third party. ', 'complianz-gdpr'),
                '2' => __('Only I can perform audits', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),


        'what-do-with-findings' => array(
            'step' => 2,
            'section' => 3,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'required' => true,
            'label' => __("What should be done with the findings of the audit?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('The processor is obliged to implement the findings as quickly as possible. ', 'complianz-gdpr'),
                '2' => __('The parties should decide together what to do with these findings. ', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),

        'audit-costs' => array(
            'step' => 2,
            'section' => 3,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'required' => true,
            'label' => __("Who is responsible for any audit costs?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('Data controller', 'complianz-gdpr'),
                '2' => __('Processor', 'complianz-gdpr'),
                '3' => __('The Processor, in case of non - trivial violations of the obligations from the processor agreement. Otherwise the data controller. ', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),

        // DATA breach
        'when-informed' => array(
            'step' => 3,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'required' => true,
            'label' => __("How quickly should the Data Controller be informed of a data breach?", 'complianz-gdpr'),
            'options' => array(
                '1' => __('Immediately (without unreasonable delay) after the leak has become known to the processor. ', 'complianz-gdpr'),
                '2' => __('Immediately (without unreasonable delay), within 24 hours after the leak has become know to the processor. ', 'complianz-gdpr'),
                '3' => __('Immediately (without unreasonable delay), within 36 hours after the leak has become know to the processor. ', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'maximize-liability' => array(
            'step' => 3,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'required' => true,
            'label' => __("Do you want to limit liability?", 'complianz-gdpr'),
            'options' => $this->yes_no,
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),

        'amount-liable' => array(
            'step' => 3,
            'source' => 'processing-eu',
            'type' => 'text',
            'default' => '',
            'placeholder' => __('0.00 €','complianz-gdpr'),
            'condition' => array('maximize-liability' =>'yes'),
            'required' => true,
            'label' => __("What is the maximum liability for violations of the processor agreement?", 'complianz-gdpr'),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'insurance' => array(
            'step' => 3,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'required' => true,
            'label' => __("Should the Processor take out liability insurance?", 'complianz-gdpr'),
            'options' => $this->yes_no,
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'max_cost_of_insurance' => array(
            'step' => 3,
            'source' => 'processing-eu',
            'type' => 'text',
            'default' => '',
            'required' => true,
            'placeholder' => __('0.00 €','complianz-gdpr'),
            'label' => __("What is the minimum amount the insurance should cover?", 'complianz-gdpr'),
            'condition' => array('insurance' => 'yes'),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'insurance_conditions' => array(
            'step' => 3,
            'source' => 'processing-eu',
            'type' => 'multicheckbox',
            'default' => '',
            'required' => true,
            'condition' => array('insurance' => 'yes'),
            'label' => __("The insurance conditions must provide at least cover for the following claims:", 'complianz-gdpr'),
            'options' => array(
                '1' => __('Data breaches.', 'complianz-gdpr'),
                '2' => __('Not complying to the processing data contract. ', 'complianz-gdpr'),
            ),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'access-to-policy' => array(
            'step' => 3,
            'source' => 'processing-eu',
            'type' => 'radio',
            'default' => '',
            'required' => true,
            'condition' => array('insurance' => 'yes'),
            'options' => $this->yes_no,
            'label' => __("Access to the insurance policy can be demanded.", 'complianz-gdpr'),
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
        'finish_setup_processing' => array(
            'step' => '4',
            'source' => 'processing-eu',
            'callback' => 'processing_last_step',
            'time' => CMPLZ_MINUTES_PER_QUESTION,
        ),
    );
